==> kdepimlibs-4.4.3-arm-1.tgz: install/doinst.sh <==
( cd usr/lib ; rm -rf libmailtransport.so.4 )
( cd usr/lib ; ln -sf libmailtransport.so.4.4.0 libmailtransport.so.4 )
( cd usr/lib ; rm -rf libkholidays.so.4 )
( cd usr/lib ; ln -sf libkholidays.so.4.4.0 libkholidays.so.4 )
( cd usr/lib ; rm -rf libkldap.so )
( cd usr/lib ; ln -sf libkldap.so.4 libkldap.so )
( cd usr/lib ; rm -rf libkldap.so.4 )
( cd usr/lib ; ln -sf libkldap.so.4.4.0 libkldap.so.4 )
( cd usr/lib ; rm -rf libakonadi-kcal.so )
( cd usr/lib ; ln -sf libakonadi-kcal.so.4 libakonadi-kcal.so )
( cd usr/lib ; rm -rf libkabc_file_core.so )
( cd usr/lib ; ln -sf libkabc_file_core.so.4 libkabc_file_core.so )
( cd usr/lib ; rm -rf libmicroblog.so.4 )
( cd usr/lib ; ln -sf libmicroblog.so.4.4.0 libmicroblog.so.4 )
( cd usr/lib ; rm -rf libkontactinterface.so )
( cd usr/lib ; ln -sf libkontactinterface.so.4 libkontactinterface.so )
( cd usr/lib ; rm -rf libakonadi-kmime.so )
( cd usr/lib ; ln -sf libakonadi-kmime.so.4 libakonadi-kmime.so )
( cd usr/lib ; rm -rf libkabc.so )
( cd usr/lib ; ln -sf libkabc.so.4 libkabc.so )
( cd usr/lib ; rm -rf libakonadi-kabc.so.4 )
( cd usr/lib ; ln -sf libakonadi-kabc.so.4.4.0 libakonadi-kabc.so.4 )
( cd usr/lib ; rm -rf libkimap.so.4 )
( cd usr/lib ; ln -sf libkimap.so.4.4.0 libkimap.so.4 )
( cd usr/lib ; rm -rf libkimap.so )
( cd usr/lib ; ln -sf libkimap.so.4 libkimap.so )
( cd usr/lib ; rm -rf libakonadi-kde.so.4 )
( cd usr/lib ; ln -sf libakonadi-kde.so.4.4.0 libakonadi-kde.so.4 )
( cd usr/lib ; rm -rf libktnef.so )
( cd usr/lib ; ln -sf libktnef.so.4 libktnef.so )
( cd usr/lib ; rm -rf libqgpgme.so.1 )
( cd usr/lib ; ln -sf libqgpgme.so.1.0.1 libqgpgme.so.1 )
( cd usr/lib ; rm -rf libkpimtextedit.so )
( cd usr/lib ; ln -sf libkpimtextedit.so.4 libkpimtextedit.so )
( cd usr/lib ; rm -rf libqgpgme.so )
( cd usr/lib ; ln -sf libqgpgme.so.1 libqgpgme.so )
( cd usr/lib ; rm -rf libgpgme++-pthread.so.2 )
( cd usr/lib ; ln -sf libgpgme++-pthread.so.2.4.0 libgpgme++-pthread.so.2 )
( cd usr/lib ; rm -rf libakonadi-contact.so.4 )
( cd usr/lib ; ln -sf libakonadi-contact.so.4.4.0 libakonadi-contact.so.4 )
( cd usr/lib ; rm -rf libakonadi-contact.so )
( cd usr/lib ; ln -sf libakonadi-contact.so.4 libakonadi-contact.so )
( cd usr/lib ; rm -rf libsyndication.so.4 )
( cd usr/lib ; ln -sf libsyndication.so.4.4.0 libsyndication.so.4 )
( cd usr/lib ; rm -rf libkontactinterface.so.4 )
( cd usr/lib ; ln -sf libkontactinterface.so.4.4.0 libkontactinterface.so.4 )
( cd usr/lib ; rm -rf libgpgme++.so.2 )
( cd usr/lib ; ln -sf libgpgme++.so.2.4.0 libgpgme++.so.2 )
( cd usr/lib ; rm -rf libkabc.so.4 )
( cd usr/lib ; ln -sf libkabc.so.4.4.0 libkabc.so.4 )
( cd usr/lib ; rm -rf libkpimtextedit.so.4 )
( cd usr/lib ; ln -sf libkpimtextedit.so.4.4.0 libkpimtextedit.so.4 )
( cd usr/lib ; rm -rf libgpgme++-pth.so )
( cd usr/lib ; ln -sf libgpgme++-pth.so.2 libgpgme++-pth.so )
( cd usr/lib ; rm -rf libkresources.so.4 )
( cd usr/lib ; ln -sf libkresources.so.4.4.0 libkresources.so.4 )
( cd usr/lib ; rm -rf libkmime.so )
( cd usr/lib ; ln -sf libkmime.so.4 libkmime.so )
( cd usr/lib ; rm -rf libgpgme++-pth.so.2 )
( cd usr/lib ; ln -sf libgpgme++-pth.so.2.4.0 libgpgme++-pth.so.2 )
( cd usr/lib ; rm -rf libkblog.so )
( cd usr/lib ; ln -sf libkblog.so.4 libkblog.so )
( cd usr/lib ; rm -rf libkxmlrpcclient.so.4 )
( cd usr/lib ; ln -sf libkxmlrpcclient.so.4.4.0 libkxmlrpcclient.so.4 )
( cd usr/lib ; rm -rf libmicroblog.so )
( cd usr/lib ; ln -sf libmicroblog.so.4 libmicroblog.so )
( cd usr/lib ; rm -rf libgpgme++.so )
( cd usr/lib ; ln -sf libgpgme++.so.2 libgpgme++.so )
( cd usr/lib ; rm -rf libkpimutils.so )
( cd usr/lib ; ln -sf libkpimutils.so.4 libkpimutils.so )
( cd usr/lib ; rm -rf libmailtransport.so )
( cd usr/lib ; ln -sf libmailtransport.so.4 libmailtransport.so )
( cd usr/lib ; rm -rf libkpimidentities.so )
( cd usr/lib ; ln -sf libkpimidentities.so.4 libkpimidentities.so )
( cd usr/lib ; rm -rf libkholidays.so )
( cd usr/lib ; ln -sf libkholidays.so.4 libkholidays.so )
( cd usr/lib ; rm -rf libkcal.so )
( cd usr/lib ; ln -sf libkcal.so.4 libkcal.so )
( cd usr/lib ; rm -rf libgpgme++-pthread.so )
( cd usr/lib ; ln -sf libgpgme++-pthread.so.2 libgpgme++-pthread.so )
( cd usr/lib ; rm -rf libkxmlrpcclient.so )
( cd usr/lib ; ln -sf libkxmlrpcclient.so.4 libkxmlrpcclient.so )
( cd usr/lib ; rm -rf libkabc_file_core.so.4 )
( cd usr/lib ; ln -sf libkabc_file_core.so.4.4.0 libkabc_file_core.so.4 )
( cd usr/lib ; rm -rf libkpimutils.so.4 )
( cd usr/lib ; ln -sf libkpimutils.so.4.4.0 libkpimutils.so.4 )
( cd usr/lib ; rm -rf libakonadi-kcal.so.4 )
( cd usr/lib ; ln -sf libakonadi-kcal.so.4.4.0 libakonadi-kcal.so.4 )
( cd usr/lib ; rm -rf libkpimidentities.so.4 )
( cd usr/lib ; ln -sf libkpimidentities.so.4.4.0 libkpimidentities.so.4 )
( cd usr/lib ; rm -rf libakonadi-kmime.so.4 )
( cd usr/lib ; ln -sf libakonadi-kmime.so.4.4.0 libakonadi-kmime.so.4 )
( cd usr/lib ; rm -rf libakonadi-kde.so )
( cd usr/lib ; ln -sf libakonadi-kde.so.4 libakonadi-kde.so )
( cd usr/lib ; rm -rf libktnef.so.4 )
( cd usr/lib ; ln -sf libktnef.so.4.4.0 libktnef.so.4 )
( cd usr/lib ; rm -rf libkresources.so )
( cd usr/lib ; ln -sf libkresources.so.4 libkresources.so )
( cd usr/lib ; rm -rf libkmime.so.4 )
( cd usr/lib ; ln -sf libkmime.so.4.4.0 libkmime.so.4 )
( cd usr/lib ; rm -rf libkblog.so.4 )
( cd usr/lib ; ln -sf libkblog.so.4.4.0 libkblog.so.4 )
( cd usr/lib ; rm -rf libkcal.so.4 )
( cd usr/lib ; ln -sf libkcal.so.4.4.0 libkcal.so.4 )
( cd usr/lib ; rm -rf libsyndication.so )
( cd usr/lib ; ln -sf libsyndication.so.4 libsyndication.so )
( cd usr/lib ; rm -rf libakonadi-kabc.so )
( cd usr/lib ; ln -sf libakonadi-kabc.so.4 libakonadi-kabc.so )
( cd usr/share/doc/HTML/en/kcontrol/kresources ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/kresources ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave/sieve ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/sieve ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave/pop3 ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/pop3 ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave/mbox ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/mbox ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave/nntp ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/nntp ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave/imap ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/imap ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave/ldap ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/ldap ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave/smtp ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/smtp ; ln -sf /usr/share/doc/HTML/en/common common )

==> kdepimlibs-4.5.5-arm-1.tgz: install/doinst.sh <==
( cd usr/share/doc/HTML/en/kcontrol/kresources ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/kresources ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave/imap ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/imap ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave/mbox ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/mbox ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave/pop3 ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/pop3 ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave/nntp ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/nntp ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave/sieve ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/sieve ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave/ldap ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/ldap ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave/smtp ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave/smtp ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/lib ; rm -rf libakonadi-kabc.so.4 )
( cd usr/lib ; ln -sf libakonadi-kabc.so.4.5.0 libakonadi-kabc.so.4 )
( cd usr/lib ; rm -rf libkpimidentities.so.4 )
( cd usr/lib ; ln -sf libkpimidentities.so.4.5.0 libkpimidentities.so.4 )
( cd usr/lib ; rm -rf libkabc.so.4 )
( cd usr/lib ; ln -sf libkabc.so.4.5.0 libkabc.so.4 )
( cd usr/lib ; rm -rf libkontactinterface.so )
( cd usr/lib ; ln -sf libkontactinterface.so.4 libkontactinterface.so )
( cd usr/lib ; rm -rf libktnef.so )
( cd usr/lib ; ln -sf libktnef.so.4 libktnef.so )
( cd usr/lib ; rm -rf libkldap.so.4 )
( cd usr/lib ; ln -sf libkldap.so.4.5.0 libkldap.so.4 )
( cd usr/lib ; rm -rf libkresources.so )
( cd usr/lib ; ln -sf libkresources.so.4 libkresources.so )
( cd usr/lib ; rm -rf libkxmlrpcclient.so )
( cd usr/lib ; ln -sf libkxmlrpcclient.so.4 libkxmlrpcclient.so )
( cd usr/lib ; rm -rf libkcal.so.4 )
( cd usr/lib ; ln -sf libkcal.so.4.5.0 libkcal.so.4 )
( cd usr/lib ; rm -rf libkcal.so )
( cd usr/lib ; ln -sf libkcal.so.4 libkcal.so )
( cd usr/lib ; rm -rf libmailtransport.so.4 )
( cd usr/lib ; ln -sf libmailtransport.so.4.5.0 libmailtransport.so.4 )
( cd usr/lib ; rm -rf libkabc_file_core.so.4 )
( cd usr/lib ; ln -sf libkabc_file_core.so.4.5.0 libkabc_file_core.so.4 )
( cd usr/lib ; rm -rf libmicroblog.so.4 )
( cd usr/lib ; ln -sf libmicroblog.so.4.5.0 libmicroblog.so.4 )
( cd usr/lib ; rm -rf libkldap.so )
( cd usr/lib ; ln -sf libkldap.so.4 libkldap.so )
( cd usr/lib ; rm -rf libakonadi-kabc.so )
( cd usr/lib ; ln -sf libakonadi-kabc.so.4 libakonadi-kabc.so )
( cd usr/lib ; rm -rf libsyndication.so.4 )
( cd usr/lib ; ln -sf libsyndication.so.4.5.0 libsyndication.so.4 )
( cd usr/lib ; rm -rf libakonadi-kmime.so.4 )
( cd usr/lib ; ln -sf libakonadi-kmime.so.4.5.0 libakonadi-kmime.so.4 )
( cd usr/lib ; rm -rf libkblog.so.4 )
( cd usr/lib ; ln -sf libkblog.so.4.5.0 libkblog.so.4 )
( cd usr/lib ; rm -rf libakonadi-kcal.so.4 )
( cd usr/lib ; ln -sf libakonadi-kcal.so.4.5.0 libakonadi-kcal.so.4 )
( cd usr/lib ; rm -rf libgpgme++.so.2 )
( cd usr/lib ; ln -sf libgpgme++.so.2.6.0 libgpgme++.so.2 )
( cd usr/lib ; rm -rf libkresources.so.4 )
( cd usr/lib ; ln -sf libkresources.so.4.5.0 libkresources.so.4 )
( cd usr/lib ; rm -rf libkholidays.so )
( cd usr/lib ; ln -sf libkholidays.so.4 libkholidays.so )
( cd usr/lib ; rm -rf libkpimtextedit.so )
( cd usr/lib ; ln -sf libkpimtextedit.so.4 libkpimtextedit.so )
( cd usr/lib ; rm -rf libkontactinterface.so.4 )
( cd usr/lib ; ln -sf libkontactinterface.so.4.5.0 libkontactinterface.so.4 )
( cd usr/lib ; rm -rf libkholidays.so.4 )
( cd usr/lib ; ln -sf libkholidays.so.4.5.0 libkholidays.so.4 )
( cd usr/lib ; rm -rf libkabc_file_core.so )
( cd usr/lib ; ln -sf libkabc_file_core.so.4 libkabc_file_core.so )
( cd usr/lib ; rm -rf libkpimutils.so.4 )
( cd usr/lib ; ln -sf libkpimutils.so.4.5.0 libkpimutils.so.4 )
( cd usr/lib ; rm -rf libakonadi-kcal.so )
( cd usr/lib ; ln -sf libakonadi-kcal.so.4 libakonadi-kcal.so )
( cd usr/lib ; rm -rf libakonadi-contact.so.4 )
( cd usr/lib ; ln -sf libakonadi-contact.so.4.5.0 libakonadi-contact.so.4 )
( cd usr/lib ; rm -rf libsyndication.so )
( cd usr/lib ; ln -sf libsyndication.so.4 libsyndication.so )
( cd usr/lib ; rm -rf libqgpgme.so )
( cd usr/lib ; ln -sf libqgpgme.so.1 libqgpgme.so )
( cd usr/lib ; rm -rf libkimap.so )
( cd usr/lib ; ln -sf libkimap.so.4 libkimap.so )
( cd usr/lib ; rm -rf libmicroblog.so )
( cd usr/lib ; ln -sf libmicroblog.so.4 libmicroblog.so )
( cd usr/lib ; rm -rf libktnef.so.4 )
( cd usr/lib ; ln -sf libktnef.so.4.5.0 libktnef.so.4 )
( cd usr/lib ; rm -rf libkpimutils.so )
( cd usr/lib ; ln -sf libkpimutils.so.4 libkpimutils.so )
( cd usr/lib ; rm -rf libkblog.so )
( cd usr/lib ; ln -sf libkblog.so.4 libkblog.so )
( cd usr/lib ; rm -rf libkpimtextedit.so.4 )
( cd usr/lib ; ln -sf libkpimtextedit.so.4.5.0 libkpimtextedit.so.4 )
( cd usr/lib ; rm -rf libkxmlrpcclient.so.4 )
( cd usr/lib ; ln -sf libkxmlrpcclient.so.4.5.0 libkxmlrpcclient.so.4 )
( cd usr/lib ; rm -rf libkabc.so )
( cd usr/lib ; ln -sf libkabc.so.4 libkabc.so )
( cd usr/lib ; rm -rf libakonadi-kmime.so )
( cd usr/lib ; ln -sf libakonadi-kmime.so.4 libakonadi-kmime.so )
( cd usr/lib ; rm -rf libgpgme++-pth.so )
( cd usr/lib ; ln -sf libgpgme++-pth.so.2 libgpgme++-pth.so )
( cd usr/lib ; rm -rf libqgpgme.so.1 )
( cd usr/lib ; ln -sf libqgpgme.so.1.0.1 libqgpgme.so.1 )
( cd usr/lib ; rm -rf libgpgme++-pthread.so )
( cd usr/lib ; ln -sf libgpgme++-pthread.so.2 libgpgme++-pthread.so )
( cd usr/lib ; rm -rf libmailtransport.so )
( cd usr/lib ; ln -sf libmailtransport.so.4 libmailtransport.so )
( cd usr/lib ; rm -rf libkmime.so.4 )
( cd usr/lib ; ln -sf libkmime.so.4.5.0 libkmime.so.4 )
( cd usr/lib ; rm -rf libgpgme++-pth.so.2 )
( cd usr/lib ; ln -sf libgpgme++-pth.so.2.6.0 libgpgme++-pth.so.2 )
( cd usr/lib ; rm -rf libakonadi-kde.so )
( cd usr/lib ; ln -sf libakonadi-kde.so.4 libakonadi-kde.so )
( cd usr/lib ; rm -rf libkpimidentities.so )
( cd usr/lib ; ln -sf libkpimidentities.so.4 libkpimidentities.so )
( cd usr/lib ; rm -rf libkimap.so.4 )
( cd usr/lib ; ln -sf libkimap.so.4.5.0 libkimap.so.4 )
( cd usr/lib ; rm -rf libakonadi-contact.so )
( cd usr/lib ; ln -sf libakonadi-contact.so.4 libakonadi-contact.so )
( cd usr/lib ; rm -rf libgpgme++-pthread.so.2 )
( cd usr/lib ; ln -sf libgpgme++-pthread.so.2.6.0 libgpgme++-pthread.so.2 )
( cd usr/lib ; rm -rf libgpgme++.so )
( cd usr/lib ; ln -sf libgpgme++.so.2 libgpgme++.so )
( cd usr/lib ; rm -rf libkmime.so )
( cd usr/lib ; ln -sf libkmime.so.4 libkmime.so )
( cd usr/lib ; rm -rf libakonadi-kde.so.4 )
( cd usr/lib ; ln -sf libakonadi-kde.so.4.5.0 libakonadi-kde.so.4 )
